#!/usr/bin/env python

'''
This sample demonstrates Canny edge detection.
..
'''

# Python 2/3 compatibility
from __future__ import print_function

import cv2 as cv
import numpy as np

# relative module
import video

# built-in module
import sys

def main():
    try:
        fn = sys.argv[1] # 尝试获取命令行参数作为视频源
    except:
        fn = 0 # 如果没有提供命令行参数，则使用默认摄像头作为视频源

    def nothing(*arg):
        pass

    # 创建一个名为 "edge" 的窗口，以全屏模式显示
    cv.namedWindow('edge',cv.WND_PROP_FULLSCREEN)    #Set the windows to be full screen.
    cv.setWindowProperty('edge', cv.WND_PROP_FULLSCREEN, cv.WINDOW_FULLSCREEN)    #Set the windows to be full screen.

    # 创建两个滑动条来调整Canny算法的阈值
    cv.createTrackbar('thrs1', 'edge', 2000, 5000, nothing)
    cv.createTrackbar('thrs2', 'edge', 4000, 5000, nothing)

    # 创建一个视频捕获对象
    cap = video.create_capture(fn)
    while True:
        # 从视频捕获对象中读取一帧
        _flag, img = cap.read()
        # 将图像转换为灰度图
        gray = cv.cvtColor(img, cv.COLOR_BGR2GRAY)
        # 获取滑动条的当前位置作为Canny算法的阈值
        thrs1 = cv.getTrackbarPos('thrs1', 'edge')
        thrs2 = cv.getTrackbarPos('thrs2', 'edge')
        # 使用Canny算法找到图像中的边缘
        edge = cv.Canny(gray, thrs1, thrs2, apertureSize=5)
        # 创建一个用于显示的图像，将边缘显示为绿色
        vis = img.copy()
        vis = np.uint8(vis/2.)
        vis[edge != 0] = (0, 255, 0)
        # 显示图像
        cv.imshow('edge', vis)
        # 检查是否按下了ESC键，如果按下则退出循环
        ch = cv.waitKey(5)
        if ch == 27:
            break

    print('Done')


if __name__ == '__main__':
    print(__doc__)
    main()
    cv.destroyAllWindows()
